searchNodes=[{"doc":"Represents a command that will be executed as a git hook task. A command should be configured as {:cmd, command, opts} , being opts an optional configuration. For example: config :git_hooks , hooks : [ pre_commit : [ { :cmd , &quot;ls -lisa&quot; , include_hook_args : true } ] ]","ref":"GitHooks.Tasks.Cmd.html","title":"GitHooks.Tasks.Cmd","type":"module"},{"doc":"Creates a new cmd struct that will execute a command. This function expects a tuple or triple with :cmd , the command to execute and the opts. Options include_hook_args : Whether the git options will be passed as argument when executing the file. You will need to check which arguments are being sent by each git hook . env : The environment variables that will be set in the execution context of the file. Examples iex&gt; Elixir.GitHooks.Tasks.Cmd . new ( { :cmd , &quot;ls -l&quot; , env : [ { &quot;var&quot; , &quot;test&quot; } ] , include_hook_args : true } , :pre_commit , [ &quot;commit message&quot; ] ) % Elixir.GitHooks.Tasks.Cmd { command : &quot;ls&quot; , original_command : &quot;ls -l&quot; , args : [ &quot;-l&quot; , &quot;commit message&quot; ] , env : [ { &quot;var&quot; , &quot;test&quot; } ] , git_hook_type : :pre_commit } iex&gt; Elixir.GitHooks.Tasks.Cmd . new ( { :cmd , &quot;ls&quot; , include_hook_args : false } , :pre_commit , [ &quot;commit message&quot; ] ) % Elixir.GitHooks.Tasks.Cmd { command : &quot;ls&quot; , original_command : &quot;ls&quot; , args : [ ] , env : [ ] , git_hook_type : :pre_commit }","ref":"GitHooks.Tasks.Cmd.html#new/3","title":"GitHooks.Tasks.Cmd.new/3","type":"function"},{"doc":"Represents a command to be executed.","ref":"GitHooks.Tasks.Cmd.html#t:t/0","title":"GitHooks.Tasks.Cmd.t/0","type":"type"},{"doc":"Represents a file that will be executed as a git hook task. A file should be configured as {:file, file_path, opts} , being opts an optional configuration. The file should be readable and have execution permissions. See Elixir.GitHooks.Tasks.File.new/1 for more information. For example: config :git_hooks , hooks : [ pre_commit : [ { :file , &quot;opt/scripts/checks&quot; , include_hook_args : true } ] ]","ref":"GitHooks.Tasks.File.html","title":"GitHooks.Tasks.File","type":"module"},{"doc":"Creates a new file struct. This function expects a tuple or triple with :file , the file path and the opts. Options include_hook_args : Whether the git options will be passed as argument when executing the file. You will need to check which arguments are being sent by each git hook . env : The environment variables that will be set in the execution context of the file. Examples iex&gt; Elixir.GitHooks.Tasks.File . new ( { :file , :test , env : [ { &quot;var&quot; , &quot;test&quot; } ] , include_hook_args : true } , :pre_commit , [ &quot;commit message&quot; ] ) % Elixir.GitHooks.Tasks.File { file_path : :test , args : [ &quot;commit message&quot; ] , env : [ { &quot;var&quot; , &quot;test&quot; } ] , git_hook_type : :pre_commit } iex&gt; Elixir.GitHooks.Tasks.File . new ( { :file , :test , include_hook_args : false } , :pre_commit , [ &quot;commit message&quot; ] ) % Elixir.GitHooks.Tasks.File { file_path : :test , args : [ ] , env : [ ] , git_hook_type : :pre_commit }","ref":"GitHooks.Tasks.File.html#new/3","title":"GitHooks.Tasks.File.new/3","type":"function"},{"doc":"Represents a file to be executed.","ref":"GitHooks.Tasks.File.html#t:t/0","title":"GitHooks.Tasks.File.t/0","type":"type"},{"doc":"Represents a {module, function, arity} (a.k.a. mfa ) that will be evaluated by the Kernel module. An mfa should be configured as {module, function, arity} . The function of the module will always receive the hook arguments and the arity is expected to match the same number to avoid any unexpected behaviour. See Elixir documentation for more information. For example: config :git_hooks , hooks : [ pre_commit : [ { MyModule , :my_function , 1 } ] ]","ref":"GitHooks.Tasks.MFA.html","title":"GitHooks.Tasks.MFA","type":"module"},{"doc":"Creates a new mfa struct. Examples iex&gt; Elixir.GitHooks.Tasks.MFA . new ( { MyModule , :my_function , 1 } , :pre_commit , [ &quot;commit message&quot; ] ) % Elixir.GitHooks.Tasks.MFA { module : MyModule , function : :my_function , args : [ &quot;commit message&quot; ] }","ref":"GitHooks.Tasks.MFA.html#new/3","title":"GitHooks.Tasks.MFA.new/3","type":"function"},{"doc":"Represents an mfa to be executed.","ref":"GitHooks.Tasks.MFA.html#t:t/0","title":"GitHooks.Tasks.MFA.t/0","type":"type"},{"doc":"Represents a Mix task that will be executed as a git hook task. A mix task should be configured as {:mix_task, task_name, task_args} , being task_args an optional configuration. See Elixir.GitHooks.Tasks.Mix.new/1 for more information. For example: config :git_hooks , hooks : [ pre_commit : [ { :mix_task , :test } , { :mix_task , :format , [ &quot;--dry-run&quot; ] } ] ] See https://hexdocs.pm/mix/Mix.Task.html#run/2 for reference.","ref":"GitHooks.Tasks.Mix.html","title":"GitHooks.Tasks.Mix","type":"module"},{"doc":"Creates a new Mix task struct. This function expects a tuple or triple with :mix_task , the task name and the task args. Examples iex&gt; Elixir.GitHooks.Tasks.Mix . new ( { :mix_task , :test , [ &quot;--failed&quot; ] } ) % Elixir.GitHooks.Tasks.Mix { task : :test , args : [ &quot;--failed&quot; ] }","ref":"GitHooks.Tasks.Mix.html#new/1","title":"GitHooks.Tasks.Mix.new/1","type":"function"},{"doc":"Represents a Mix task.","ref":"GitHooks.Tasks.Mix.html#t:t/0","title":"GitHooks.Tasks.Mix.t/0","type":"type"},{"doc":"Installs the configured git hooks. Before installing the new hooks, the already hooks files are backed up with the extension .pre_git_hooks_backup . Command line options --quiet - disables the output of the files that are being copied/backed up To manually install the git hooks run: mix git_hooks . install `","ref":"Mix.Tasks.GitHooks.Install.html","title":"Mix.Tasks.GitHooks.Install","type":"task"},{"doc":"Runs all the configured mix tasks for a given git hook. Any git hook is supported. Examples You can run any hook by running mix git_hooks.run hook_name . For example: mix git_hooks . run pre_commit You can also all the hooks which are configured with mix git_hooks.run all .","ref":"Mix.Tasks.GitHooks.Run.html","title":"Mix.Tasks.GitHooks.Run","type":"task"},{"doc":"Runs a task for a given git hook. The task can be one of three different types: {:cmd, &quot;command arg1 arg2&quot;} : Runs a command. {:file, &quot;path_to_file&quot;} : Runs an executable file. &quot;command arg1 arg2&quot; : Runs a simple command, supports no options. The first two options above can use a third element in the tuple, see here more info about the options.","ref":"Mix.Tasks.GitHooks.Run.html#run/1","title":"Mix.Tasks.GitHooks.Run.run/1","type":"function"},{"doc":"Run options: include_hook_args : Whether the git hook args should be sent to the command to be executed. In case of true , the args will be amended to the command. Defaults to false .","ref":"Mix.Tasks.GitHooks.Run.html#t:run_opts/0","title":"Mix.Tasks.GitHooks.Run.run_opts/0","type":"type"},{"doc":"","ref":"code_of_conduct.html","title":"Code of Conduct","type":"extras"},{"doc":"In the interest of fostering an open and welcoming environment, we as contributors and maintainers pledge to making participation in our project and our community a harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation.","ref":"code_of_conduct.html#our-pledge","title":"Code of Conduct - Our Pledge","type":"extras"},{"doc":"Examples of behavior that contributes to creating a positive environment include: Using welcoming and inclusive language Being respectful of differing viewpoints and experiences Gracefully accepting constructive criticism Focusing on what is best for the community Showing empathy towards other community members Examples of unacceptable behavior by participants include: The use of sexualized language or imagery and unwelcome sexual attention or advances Trolling, insulting/derogatory comments, and personal or political attacks Public or private harassment Publishing others' private information, such as a physical or electronic address, without explicit permission Other conduct which could reasonably be considered inappropriate in a professional setting","ref":"code_of_conduct.html#our-standards","title":"Code of Conduct - Our Standards","type":"extras"},{"doc":"Project maintainers are responsible for clarifying the standards of acceptable behavior and are expected to take appropriate and fair corrective action in response to any instances of unacceptable behavior. Project maintainers have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct, or to ban temporarily or permanently any contributor for other behaviors that they deem inappropriate, threatening, offensive, or harmful.","ref":"code_of_conduct.html#our-responsibilities","title":"Code of Conduct - Our Responsibilities","type":"extras"},{"doc":"This Code of Conduct applies both within project spaces and in public spaces when an individual is representing the project or its community. Examples of representing a project or community include using an official project e-mail address, posting via an official social media account, or acting as an appointed representative at an online or offline event. Representation of a project may be further defined and clarified by project maintainers.","ref":"code_of_conduct.html#scope","title":"Code of Conduct - Scope","type":"extras"},{"doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by contacting the project team at qgadrian@users.noreply.github.com. All complaints will be reviewed and investigated and will result in a response that is deemed necessary and appropriate to the circumstances. The project team is obligated to maintain confidentiality with regard to the reporter of an incident. Further details of specific enforcement policies may be posted separately. Project maintainers who do not follow or enforce the Code of Conduct in good faith may face temporary or permanent repercussions as determined by other members of the project's leadership.","ref":"code_of_conduct.html#enforcement","title":"Code of Conduct - Enforcement","type":"extras"},{"doc":"This Code of Conduct is adapted from the Contributor Covenant , version 1.4, available at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html For answers to common questions about this code of conduct, see https://www.contributor-covenant.org/faq","ref":"code_of_conduct.html#attribution","title":"Code of Conduct - Attribution","type":"extras"},{"doc":"MIT License Copyright (c) 2018 Adrián Quintás Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"GitHooks 🪝 Configure git hooks in your Elixir projects. Main features: Simplicity : Automatic or manually install the configured git hook actions. Flexibility : You choose what to use to define the git hooks actions: Bash commands Executable files Elixir modules No limits : Any git hook is and will be supported out of the box, you can check here the git hooks list available.","ref":"readme.html","title":"README","type":"extras"},{"doc":"Installation Backup current hooks Automatic installation Manual installation Configuration Auto install Hook configuration Git submodules Custom project path Custom mix path Troubleshooting in docker containers Example config Task types Mix task Command Executable file Elixir module Removing a hook Execution Automatic execution Manual execution Copyright and License","ref":"readme.html#table-of-contents","title":"README - Table of Contents","type":"extras"},{"doc":"Add to dependencies: def deps do [ { :git_hooks , &quot;~&gt; 0.7.0&quot; , only : [ :dev ] , runtime : false } ] end Then install and compile the dependencies: mix deps.get &amp;&amp; mix deps.compile Backup current hooks This library will backup automatically your current git hooks before overwriting them. The backup files will have the file extension .pre_git_hooks_backup . Automatic installation This library will install automatically the configured git hooks in your config.exs file. See configuration to disable the automatic install. Manual installation You can manually install the configured git hooks at any time by running: mix git_hooks.install","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"Auto install To disable the automatic install of the git hooks set the configuration key auto_install to false . Hook configuration One or more git hooks can be configured, those hooks will be the ones installed in your git project. Currently there are supported two configuration options: tasks : A list of the commands that will be executed when running a git hook. See types of tasks for more info. verbose : If true, the output of the mix tasks will be visible. This can be configured globally or per git hook. branches : Allow or forbid the hook configuration to run (or not) in certain branches using whitelist or blacklist configuration (see example below). You can use regular expressions to match a branch name. Git submodules This library supports git submodules, just add your git_hooks configuration to any of the submodules projects. Setting a custom git hooks config path is also supported: git config core . hooksPath . myCustomGithooks / Custom project path This library assumes a simple Elixir project architecture. This is, an Elixir project in the root of a git repository. If you have a different project architecture, you can specify the absolute path of your project using the project_path configuration: { project_path , 0 } = System . cmd ( &quot;pwd&quot; , [ ] ) project_path = String . replace ( project_path , ~r/ \\n / , &quot;/&quot; ) config :git_hooks , hooks : [ pre_commit : [ tasks : [ { :cmd , &quot;mix format --check-formatted&quot; } ] ] ] , project_path : project_path Custom mix path This library expects elixir to be installed in your system and the mix binary to be available. If you want to provide a specific path to run the mix executable, it can be done using the mix_path configuration. The following example would run the hooks on a docker container: config :git_hooks , auto_install : false , mix_path : &quot;docker-compose exec mix&quot; , Troubleshooting in docker containers The mix_path configuration can be used to run mix hooks on a Docker container. If you have a TTY error running mix in a Docker container use docker exec --tty $(docker-compose ps -q web) mix as the mix_path . See this issue as reference. Example config In config/config.exs use Mix.Config # somewhere in your config file if Mix . env ( ) == :dev do config :git_hooks , auto_install : true , verbose : true , branches : [ whitelist : [ &quot;feature-.*&quot; ] , blacklist : [ &quot;master&quot; ] ] , hooks : [ pre_commit : [ tasks : [ { :cmd , &quot;mix format --check-formatted&quot; } ] ] , pre_push : [ verbose : false , tasks : [ { :cmd , &quot;mix dialyzer&quot; } , { :cmd , &quot;mix test --color&quot; } , { :cmd , &quot;echo &#39;success!&#39;&quot; } ] ] ] end Task types For more information, check the module documentation for each of the different supported tasks. Mix task This is the preferred option to run mix tasks, as it will provide the best execution feedback. Just add in your config the mix tasks you want to run. You can also set the args to be used by the mix task: config :git_hooks , verbose : true , hooks : [ commit_msg : [ tasks : [ { :mix_task , :test } , { :mix_task , :format , [ &quot;--dry-run&quot; ] } ] ] ] By default this library expects by default the following return values from mix tasks: 0 :ok nil If you want to support additional success return values from your mix tasks, you can add them by adding the following configuration: config :git_hooks , extra_success_returns : [ { :noop , [ ] } , { :ok , [ ] } ] Command To run a simple command you can either declare a string or a tuple with the command you want to run. For example, having &quot;mix test&quot; and {:cmd, &quot;mix test&quot;} in the hook tasks will be equivalent. If you want to forward the git hook arguments, add the option include_hook_args: true . config :git_hooks , verbose : true , hooks : [ commit_msg : [ tasks : [ { :cmd , &quot;echo &#39;test&#39;&quot; } , { :cmd , &quot;elixir ./priv/test_task.ex&quot; , include_hook_args : true } , ] ] ] Executable file The following configuration uses a script file to be run with a git hook. If you want to forward the git hook arguments, add the option include_hook_args: true . config :git_hooks , verbose : true , hooks : [ commit_msg : [ tasks : [ { :file , &quot;./priv/test_script&quot; } , { :file , &quot;./priv/test_script_with_args&quot; , include_hook_args : true } , ] ] ] The script file executed will receive the arguments from git, so you can use them as you please. Elixir module It is also possible to use Elixir modules to execute actions for a given git hook. Just add in your config the MFA ( {module, function, arity} ) definition: config :git_hooks , verbose : true , hooks : [ commit_msg : [ tasks : [ { MyModule , :execute , 2 } ] ] ] To check how many args you function should expect check the git documentation to know which parameters are being sent on each hook.","ref":"readme.html#configuration","title":"README - Configuration","type":"extras"},{"doc":"When a git hook configuration is removed, the installed hook will automatically delete it. Any backup done at the moment will still be kept.","ref":"readme.html#removing-a-hook","title":"README - Removing a hook","type":"extras"},{"doc":"Automatic execution The configured mix tasks will run automatically for each git hook . Manual execution You can also run manually any configured git hook as well. The following example will run the pre_commit configuration: mix git_hooks.run pre_commit It is also possible to run all the configured hooks: mix git_hooks.run all","ref":"readme.html#execution","title":"README - Execution","type":"extras"},{"doc":"Copyright © 2022 Adrián Quintás Source code is released under the MIT license .","ref":"readme.html#copyright-and-license","title":"README - Copyright and License","type":"extras"}]